from django.core.paginator import Paginator
from django.utils.translation import ugettext as _
from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from jmb.showcase.models import Item
from jmb.showcase.cms.models import ItemSettings


###################################
## CMS PLUGINS                    #
###################################

class ItemPlugin(CMSPluginBase):
    model = ItemSettings
    name = _("Showcase Item List")
    module = _("Showcase")

    def render(self, context, instance, placeholder):
            page=1
            self.render_template = instance.template_name
            objects = Item.objects.filter(status=1)

            ordering = instance.ordering.lower().replace(" ","").split(",")

            if instance.slugs_included:
                slugs_inclusions = instance.slugs_included.replace(" ","").split(",")
                objects = objects.filter(slug__in=slugs_inclusions)
            if instance.tales_included:
                tales_inclusions = instance.tales_included.replace(" ","").split(",")
                objects = objects.filter(tale__in=tales_inclusions)
            if instance.slugs_excluded:
                slugs_exclusions = instance.slugs_excluded.lower().replace(" ","").split(",")
                objects = objects.exclude(slug__in=slugs_exclusions)
            if instance.tales_excluded:
                tales_exclusions = instance.tales_excluded.lower().replace(" ","").split(",")
                objects = objects.exclude(tale__in=tales_exclusions)

            objects = objects.order_by(*ordering)

            request = context['request']
            if request.GET:
                if 'page' in request.GET:
                    page = request.GET['page']

            paginator = Paginator(objects, instance.objects_per_page)
            objects = paginator.page(page)
            print objects
            context.update({
                'objects': objects,
                'instance': instance,
                'placeholder': placeholder,
            })
            return context

plugin_pool.register_plugin(ItemPlugin)


