# -*- coding: utf-8 -*-
import os
import datetime
from django.db import models
from django.template.defaultfilters import slugify
from django.conf import settings
from django.utils.translation import ugettext_lazy as _


from jmb.core.db.fields import HTMLField, HTMLFieldTinyMCE
from jmb.core.db.models import StatusModel, DateModel, UserModel, OrderedModel



class Item(StatusModel, DateModel, UserModel, OrderedModel):
    tale = models.CharField(
        max_length=100,
        null=True,blank=True,
        default=settings.SHOWCASE_ITEM_TALE_DEFAULT,
        help_text=_("in future we may have more tales for showing dynamic content"),
    )
    title = models.CharField(
        _("Title"),
        max_length=200
    )
    slug = models.SlugField(
        _("Slug")
    )
    content = HTMLFieldTinyMCE(
        _("Content"),
        blank=True,null=True,
        help_text=_("Full description"),
    )
    image = models.ImageField(
        _("Image"),
        blank=True, null=True,
        upload_to = settings.SHOWCASE_ITEM_IMAGE_UPLOAD_TO,
        help_text = _("if 'show_image' is checked, this one will be showed")
    )
    link = models.URLField(
        _("Link"),
        blank=True,null=True,
        help_text= _("if link_type is external content, this link will be opened")
    )
    file = models.FileField(
        _("File"),
        blank=True,null=True,
        upload_to = settings.SHOWCASE_ITEM_FILE_UPLOAD_TO,
        help_text = _("if link_type is downloadable content, this item will be downloaded")
    )
    publication_date = models.DateField(
        _("Publication date"),
        default=datetime.date.today()
    )
    show_image = models.BooleanField(
        _("Show image"),
        default=True
    )
    show_link = models.BooleanField(
        _("Show link"),
        default=True
    )
    link_type = models.CharField(
        _("Link type"),
        max_length=3,
        choices=settings.SHOWCASE_LINK_TYPES,
        default='int'
    )

    class Meta:
        ordering = ["title","-publication_date"]
    def __unicode__(self):
        return self.title

#import cms stuffs
if settings.CMS_ENABLED:
    import jmb.showcase.cms.plugins
    import jmb.showcase.cms.app
